@@ -92,7 +92,8 @@ def get_peptide_table_df(output):
             peptide_table = pd.DataFrame(r['table_data'], columns=r['table_columns'])
             for c in peptide_table.columns:
                 for field in ['ic50', 'score', 'percentile',]:
-                    if field in c.lower():
+                    if c.lower().endswith(field):
+                        print(f"converting {c} to float")
                         peptide_table[c] = peptide_table[c].replace({'-': np.nan})
                         peptide_table[c] = peptide_table[c].astype('float64')
             return peptide_table
