@@ -77,8 +77,14 @@ def get_peptide_list_with_sequencenumber(input_sequence_text):
         if peptide_pair not in peptide_pair_set:
             peptide_pair_set.add(peptide_pair)
             peptidea, peptideb = peptide_pair
-            table_data.append((seq_num,peptidea, peptideb))
-            seq_num += 1
+            # remove peptides longer than 14 or shorter than 8
+            if len(peptidea) < 8 or len(peptideb) < 8 or len(peptidea) > 14 or len(peptideb) > 14:
+                print(f"Warning: exclude peptide pair {peptidea} and {peptideb} from prediction which is not in the range of 8-14")
+            else:
+                table_data.append((seq_num,peptidea, peptideb))
+                seq_num += 1
+    # remove crosponding rows from input_sequence_rows as well if peptides longer than 14 or shorter than 8
+    input_sequence_rows = [row for row in input_sequence_rows if len(row[0]) >= 8 and len(row[1]) >= 8 and len(row[0]) <= 14 and len(row[1]) <= 14]
     table_columns = [
         "core.sequence_number",
         "core.peptide-peptideA",
